/****************************************************************************
**
** mysms - Send & receive all your SMS on your Notebook, PC or tablet – like on your smartphone
** Copyright (C) 2013 Up To Eleven
** All rights reserved.
**
**
** This library is free software.  either version 2.1 of the License, or (at your option) any later version.
** you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation;
** either version 2.1 of the License, or (at your option) any later version.
**
**
** This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
** Without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU Lesser General Public License for more details.
**
** You should have received a copy of the GNU Lesser General Public License along with this library;
** if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
**
****************************************************************************/

#include "soundselector.h"

#if QT_VERSION >= 0x050000
    #include <QDebug>
#elif defined(Q_OS_LINUX)
    #include <phonon/AudioOutput>
    #include <phonon/MediaObject>
    #include <phonon/MediaSource>
#else
    #include <QSound>
#endif

#include <QApplication>
#include <QDir>

SoundSelector* SoundSelector::mSoundSelector = NULL;

const QString* playList[PLAYLISTSIZE] =
{
    new QString("mysms"),
    new QString("bottle-open"), new QString("can-open"),        new QString("coffee-cup"),
    new QString("coin-drop"),   new QString("glass-clink"),
    new QString("page-flip"),   new QString("snap"),            new QString("squeeze-toy"),
    new QString("stamp"),       new QString("zippo-close")
};

SoundSelector::SoundSelector()
{
#if QT_VERSION >= 0x050000
    m_audioOutput = NULL;
#endif
}

SoundSelector* SoundSelector::getInstance()
{
    if (mSoundSelector == NULL )
    {
        mSoundSelector = new SoundSelector();
    }

    return mSoundSelector;
}

void SoundSelector::playSound(int index)
{
    if (index < PLAYLISTSIZE)
    {

        QString soundsPath = QApplication::applicationDirPath() + "/sounds";

#if defined(Q_OS_LINUX)
        if (!QDir(soundsPath).exists())
            soundsPath = "/usr/share/sounds/" + QApplication::applicationName();
#endif

#if QT_VERSION >= 0x050000

        if (m_audioOutput && m_audioOutput->state() == QAudio::ActiveState)
            return;

        m_soundFile.setFileName(soundsPath);
        m_soundFile.open(QIODevice::ReadOnly);

        QAudioFormat format;
        format.setChannelCount(1);
        format.setSampleRate(8000);
        format.setSampleType(QAudioFormat::UnSignedInt);
        format.setSampleSize(8);
        format.setCodec("audio/pcm");
        format.setByteOrder(QAudioFormat::LittleEndian);

        QAudioDeviceInfo info(QAudioDeviceInfo::defaultOutputDevice());

        if (!info.isFormatSupported(format)) {
            qWarning() << "raw audio format not supported by backend, cannot play audio.";
            return;
        }

        m_audioOutput = new QAudioOutput(format, this);
        connect(m_audioOutput,SIGNAL(stateChanged(QAudio::State)),SLOT(handleAudioOuputState(QAudio::State)));
        m_audioOutput->start(&m_soundFile);

#elif defined(Q_OS_LINUX)
        Phonon::MediaObject *sound =
            Phonon::createPlayer(
                Phonon::MusicCategory,
                Phonon::MediaSource(soundsPath + "/" + (*playList[index]) + ".wav")
            );
        sound->play();
#else
        QSound::play(soundsPath + "/" + (*playList[index]) + ".wav");  // QSound has problems with resource dir, therefore absolute path is necessary
#endif

    }
}

#if QT_VERSION >= 0x050000
void SoundSelector::handleAudioOuputState(QAudio::State state)
{
    qDebug() << "player changed state" << state;

    if (state == QAudio::IdleState) {
        m_audioOutput->stop();
        m_soundFile.close();
        delete m_audioOutput;
    }
}
#endif

QString SoundSelector::getSoundTitle(int index) const
{
    if (index < PLAYLISTSIZE)
    {
        return *playList[index];
    }

    return "";
}
